#!/usr/bin/env perl
use strict;
use warnings;
use feature 'say';

my %data;
my $maxrefs = 0;

while (<>){
    s/[\r\n]+$//;
    my ($id, $noisy, $clean, $trans) = split /\t/, $_;
    next if !$id;
    if (!$data{$id}){
        $data{$id}{noisy} = $noisy;
        $data{$id}{clean} = '';
        $data{$id}{trans} = '';
        $data{$id}{refs} = 0;
    }
    if ($data{$id}{noisy} ne $noisy){
        warn "mismatch for $id:\n$data{$id}{noisy}\nvs\n$noisy\n\n";
    } else {
        $data{$id}{refs}++;
        $maxrefs = $data{$id}{refs} if $data{$id}{refs} > $maxrefs;
        $data{$id}{clean} .= $clean . "\t";
        $data{$id}{trans} .= $trans . "\t";
    }
}
warn "maxrefs=$maxrefs\n";

open my $NOISY, '>', 'noisy.txt';
open my $CLEAN, '>', 'clean.txt';
open my $TRANS, '>', 'trans.txt';
open my $IDS,   '>', 'ids.txt';

for my $id (sort keys %data) {
    next if $data{$id}{clean} =~ /LANG/;
    my $noisy = $data{$id}{noisy};
    my @clean = grep {/./} split /\t/, $data{$id}{clean};
    my @trans = grep {/./} split /\t/, $data{$id}{trans};
    die "$id" if not defined $trans[0];
    for my $i ($#clean+1 .. $maxrefs-1){$clean[$i] = $clean[0];}
    for my $i ($#trans+1 .. $maxrefs-1){$trans[$i] = $trans[0];} 
    say {$IDS} $id;
    say {$NOISY} $noisy;
    say {$CLEAN} join "\t", @clean;
    say {$TRANS} join "\t", @trans;
}

